subset.xbal: Select variables, strata, and statistics from a xbal object
Description
If any of the arguments are not specified, all the of
relevant items are included.Usage
## S3 method for class 'xbal':
subset(x, vars = NULL, strata = NULL,
stats = NULL, tests = NULL, ...)Arguments
x
The xbal object, the result of a call to
xBalance vars
The variable names to select.
strata
The strata names to select.
stats
The names of the variable level statistics
to select.
tests
The names of the group level tests to
select.
...
Other arguments (ignored)
Value
- A
xbal object with just the appropriate items
selected.